@@ -32,7 +32,7 @@ class Irmo(MCDM):
                 else:
                     
                     # Best item value
-                    if (idx == nbr_rounds - 1 and self.preferences[i] == "min") or (idx != nbr_rounds - 1 and self.preferences[i] == "max"):
+                    if (idx == nbr_rounds - 1 and self.preferences[idx] == "min") or (idx != nbr_rounds - 1 and self.preferences[idx] == "max"):
                         insert_value = math.inf
                     else:
                         insert_value = -math.inf
